@@ -19,7 +19,7 @@ from .transferer import Transferer
 from .exception import NonExistentBucket, RestrictedBucket
 from .file_version import FileVersionInfoFactory, FileIdAndName
 from .part import PartFactory
-from .raw_api import B2RawApi
+from .raw_api import API_VERSION, B2RawApi
 from .session import B2Session
 from .utils import B2TraceMeta, b2_url_encode, limit_trace_arguments
 
@@ -34,7 +34,7 @@ def url_for_api(info, api_name):
         base = info.get_download_url()
     else:
         base = info.get_api_url()
-    return base + '/b2api/v1/' + api_name
+    return '%s/b2api/%s/%s' % (base, API_VERSION, api_name)
 
 
 @six.add_metaclass(B2TraceMeta)
@@ -126,40 +126,13 @@ class B2Api(object):
         response = self.raw_api.authorize_account(realm_url, account_id_or_key_id, application_key)
         allowed = response['allowed']
 
-        # If there is a bucket restriction, get the name of the bucket.
-        # And, if we have a list of the one allowed bucket, go ahead and
-        # save it.
-        if 'listBuckets' in allowed['capabilities']:
-            if allowed['bucketId'] is not None:
-                allowed_bucket_response = self.raw_api.list_buckets(
-                    api_url=response['apiUrl'],
-                    account_auth_token=response['authorizationToken'],
-                    account_id=response['accountId'],
-                    bucket_id=allowed['bucketId'],
-                )
-                allowed_bucket_list = allowed_bucket_response['buckets']
-                allowed_bucket_count = len(allowed_bucket_list)
-                assert allowed_bucket_count in [0, 1]
-                if allowed_bucket_count == 0:
-                    # bucket has been deleted since the key was made
-                    allowed['bucketName'] = None
-                else:
-                    allowed['bucketName'] = allowed_bucket_list[0]['bucketName']
-                    self.cache.set_bucket_name_cache(
-                        BucketFactory.from_api_response(self, allowed_bucket_response)
-                    )
-            else:
-                allowed['bucketName'] = None
-        else:
-            allowed['bucketName'] = None
-
         # Store the auth data
         self.account_info.set_auth_data(
             response['accountId'],
             response['authorizationToken'],
             response['apiUrl'],
             response['downloadUrl'],
-            response['minimumPartSize'],
+            response['recommendedPartSize'],
             application_key,
             realm,
             allowed,
@@ -223,7 +196,7 @@ class B2Api(object):
 
         # Second, ask the service
         for bucket in self.list_buckets(bucket_name=bucket_name):
-            assert bucket.name == bucket_name
+            assert bucket.name.lower() == bucket_name.lower()
             return bucket
 
         # There is no such bucket.
