@@ -8,6 +8,7 @@
 #
 ######################################################################
 
+import collections
 import re
 import time
 
@@ -62,7 +63,6 @@ class KeySimulator(object):
         self.capabilities = capabilities
         self.expiration_timestamp_or_none = expiration_timestamp_or_none
         self.bucket_id_or_none = bucket_id_or_none
-        self.bucket_name_or_none = bucket_name_or_none
         self.name_prefix_or_none = name_prefix_or_none
 
     def as_key(self):
@@ -93,7 +93,6 @@ class KeySimulator(object):
         """
         return dict(
             bucketId=self.bucket_id_or_none,
-            bucketName=self.bucket_name_or_none,
             capabilities=self.capabilities,
             namePrefix=self.name_prefix_or_none,
         )
@@ -159,16 +158,28 @@ class FileSimulator(object):
         """
         return (self.name, self.file_id)
 
-    def as_download_headers(self):
-        # range has to be added by the caller!
+    def as_download_headers(self, range_=None):
+        if self.data_bytes is None:
+            content_length = 0
+        elif range_ is not None:
+            if range_[1] >= len(self.data_bytes):  # requested too much
+                content_length = len(self.data_bytes)
+            else:
+                content_length = range_[1] - range_[0] + 1
+        else:
+            content_length = len(self.data_bytes)
         headers = {
-            'content-length': len(self.data_bytes) if self.data_bytes is not None else 0,
+            'content-length': content_length,
             'content-type': self.content_type,
             'x-bz-content-sha1': self.content_sha1,
             'x-bz-upload-timestamp': self.upload_timestamp,
             'x-bz-file-id': self.file_id,
             'x-bz-file-name': self.name,
-        }  # yapf: disable
+        }
+        if range_ is not None:
+            headers['Content-Range'] = 'bytes %d-%d/%d' % (
+                range_[0], range_[0] + content_length, len(self.data_bytes)
+            )  # yapf: disable
         for key, value in six.iteritems(self.file_info):
             headers['x-bz-info-' + key] = value
         return headers
@@ -322,11 +333,11 @@ class BucketSimulator(object):
         del self.file_id_to_file[file_id]
         return dict(fileId=file_id, fileName=file_name, uploadTimestamp=file_sim.upload_timestamp)
 
-    def download_file_by_id(self, file_id, range_=None):
+    def download_file_by_id(self, file_id, url, range_=None):
         file_sim = self.file_id_to_file[file_id]
-        return self._download_file_sim(file_sim, range_=range_)
+        return self._download_file_sim(file_sim, url, range_=range_)
 
-    def download_file_by_name(self, file_name, range_=None):
+    def download_file_by_name(self, file_name, url, range_=None):
         files = self.list_file_names(file_name, 1)['files']
         if len(files) == 0:
             raise FileNotPresent(file_name)
@@ -334,10 +345,10 @@ class BucketSimulator(object):
         if file_dict['fileName'] != file_name or file_dict['action'] != 'upload':
             raise FileNotPresent(file_name)
         file_sim = self.file_name_and_id_to_file[(file_name, file_dict['fileId'])]
-        return self._download_file_sim(file_sim, range_=range_)
+        return self._download_file_sim(file_sim, url, range_=range_)
 
-    def _download_file_sim(self, file_sim, range_=None):
-        return ResponseContextManager(FakeResponse(file_sim, range_))
+    def _download_file_sim(self, file_sim, url, range_=None):
+        return ResponseContextManager(FakeResponse(file_sim, url, range_))
 
     def finish_large_file(self, file_id, part_sha1_array):
         file_sim = self.file_id_to_file[file_id]
@@ -526,7 +537,7 @@ class RawSimulator(AbstractRawApi):
     DOWNLOAD_URL_MATCHER = re.compile(
         DOWNLOAD_URL + '(?:' + '|'.join(
             (
-                '/b2api/v1/b2_download_file_by_id\?fileId=(?P<file_id>[^/]+)',
+                '/b2api/v[0-9]+/b2_download_file_by_id\?fileId=(?P<file_id>[^/]+)',
                 '/file/(?P<bucket_name>[^/]+)/(?P<file_name>.+)',
             )
         ) + ')$'
@@ -612,13 +623,20 @@ class RawSimulator(AbstractRawApi):
         auth_token = 'auth_token_%d' % (self.auth_token_counter,)
         self.auth_token_counter += 1
         self.auth_token_to_key[auth_token] = key_sim
+        allowed = key_sim.get_allowed()
+        bucketId = allowed.get('bucketId')
+        if (bucketId is not None) and (bucketId in self.bucket_id_to_bucket):
+            allowed['bucketName'] = self.bucket_id_to_bucket[bucketId].bucket_name
+        else:
+            allowed['bucketName'] = None
         return dict(
             accountId=key_sim.account_id,
             authorizationToken=auth_token,
             apiUrl=self.API_URL,
             downloadUrl=self.DOWNLOAD_URL,
-            minimumPartSize=self.MIN_PART_SIZE,
-            allowed=key_sim.get_allowed(),
+            recommendedPartSize=self.MIN_PART_SIZE,
+            absoluteMinimumPartSize=self.MIN_PART_SIZE,
+            allowed=allowed,
         )
 
     def cancel_large_file(self, api_url, account_auth_token, file_id):
@@ -717,10 +735,10 @@ class RawSimulator(AbstractRawApi):
         if file_id is not None:
             bucket_id = self.file_id_to_bucket_id[file_id]
             bucket = self._get_bucket_by_id(bucket_id)
-            return bucket.download_file_by_id(file_id, range_=range_)
+            return bucket.download_file_by_id(file_id, range_=range_, url=url)
         elif bucket_name is not None and file_name is not None:
             bucket = self._get_bucket_by_name(bucket_name)
-            return bucket.download_file_by_name(b2_url_decode(file_name), range_=range_)
+            return bucket.download_file_by_name(b2_url_decode(file_name), range_=range_, url=url)
         else:
             assert False
 
@@ -964,13 +982,17 @@ class RawSimulator(AbstractRawApi):
         return self.bucket_name_to_bucket[bucket_name]
 
 
+FakeRequest = collections.namedtuple('FakeRequest', 'url headers')
+
+
 class FakeResponse(object):
-    def __init__(self, file_sim, range_=None):
+    def __init__(self, file_sim, url, range_=None):
         self.data_bytes = file_sim.data_bytes
-        self.headers = file_sim.as_download_headers()
+        self.headers = file_sim.as_download_headers(range_)
+        self.url = url
+        self.range_ = range_
         if range_ is not None:
             self.data_bytes = self.data_bytes[range_[0]:range_[1] + 1]
-            self.headers['Content-Range'] = '%s-%s' % range_
 
     def iter_content(self, chunk_size=1):
         start = 0
@@ -978,5 +1000,12 @@ class FakeResponse(object):
             yield self.data_bytes[start:start + chunk_size]
             start += chunk_size
 
+    @property
+    def request(self):
+        headers = {}
+        if self.range_ is not None:
+            headers['Range'] = '%s-%s' % self.range_
+        return FakeRequest(self.url, headers)
+
     def close(self):
         pass
